"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_CONFIG_BASED_ISSUANCE_FIELD_NUMBER: builtins.int
    ALLOW_CSR_BASED_ISSUANCE_FIELD_NUMBER: builtins.int
    allow_config_based_issuance: builtins.bool
    allow_csr_based_issuance: builtins.bool
    def __init__(
        self,
        *,
        allow_config_based_issuance: builtins.bool = ...,
        allow_csr_based_issuance: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_config_based_issuance", b"allow_config_based_issuance", "allow_csr_based_issuance", b"allow_csr_based_issuance"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes = PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SIGNATURE_ALGORITHM_FIELD_NUMBER: builtins.int
    signature_algorithm: builtins.str
    def __init__(
        self,
        *,
        signature_algorithm: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["signature_algorithm", b"signature_algorithm"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve = PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAX_MODULUS_SIZE_FIELD_NUMBER: builtins.int
    MIN_MODULUS_SIZE_FIELD_NUMBER: builtins.int
    max_modulus_size: builtins.str
    min_modulus_size: builtins.str
    def __init__(
        self,
        *,
        max_modulus_size: builtins.str = ...,
        min_modulus_size: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["max_modulus_size", b"max_modulus_size", "min_modulus_size", b"min_modulus_size"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa = PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ELLIPTIC_CURVE_FIELD_NUMBER: builtins.int
    RSA_FIELD_NUMBER: builtins.int
    @property
    def elliptic_curve(self) -> global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve: ...
    @property
    def rsa(self) -> global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa: ...
    def __init__(
        self,
        *,
        elliptic_curve: global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXEllipticCurve | None = ...,
        rsa: global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypesXRsa | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["elliptic_curve", b"elliptic_curve", "rsa", b"rsa"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["elliptic_curve", b"elliptic_curve", "rsa", b"rsa"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes = PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRITICAL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    critical: builtins.bool
    value: builtins.str
    @property
    def object_id(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId: ...
    def __init__(
        self,
        *,
        critical: builtins.bool = ...,
        value: builtins.str = ...,
        object_id: global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensionsXObjectId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["critical", b"critical", "object_id", b"object_id", "value", b"value"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_CA_FIELD_NUMBER: builtins.int
    MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    NON_CA_FIELD_NUMBER: builtins.int
    ZERO_MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    is_ca: builtins.bool
    max_issuer_path_length: builtins.float
    non_ca: builtins.bool
    zero_max_issuer_path_length: builtins.bool
    def __init__(
        self,
        *,
        is_ca: builtins.bool = ...,
        max_issuer_path_length: builtins.float = ...,
        non_ca: builtins.bool = ...,
        zero_max_issuer_path_length: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_ca", b"is_ca", "max_issuer_path_length", b"max_issuer_path_length", "non_ca", b"non_ca", "zero_max_issuer_path_length", b"zero_max_issuer_path_length"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_SIGN_FIELD_NUMBER: builtins.int
    CONTENT_COMMITMENT_FIELD_NUMBER: builtins.int
    CRL_SIGN_FIELD_NUMBER: builtins.int
    DATA_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    DECIPHER_ONLY_FIELD_NUMBER: builtins.int
    DIGITAL_SIGNATURE_FIELD_NUMBER: builtins.int
    ENCIPHER_ONLY_FIELD_NUMBER: builtins.int
    KEY_AGREEMENT_FIELD_NUMBER: builtins.int
    KEY_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    cert_sign: builtins.bool
    content_commitment: builtins.bool
    crl_sign: builtins.bool
    data_encipherment: builtins.bool
    decipher_only: builtins.bool
    digital_signature: builtins.bool
    encipher_only: builtins.bool
    key_agreement: builtins.bool
    key_encipherment: builtins.bool
    def __init__(
        self,
        *,
        cert_sign: builtins.bool = ...,
        content_commitment: builtins.bool = ...,
        crl_sign: builtins.bool = ...,
        data_encipherment: builtins.bool = ...,
        decipher_only: builtins.bool = ...,
        digital_signature: builtins.bool = ...,
        encipher_only: builtins.bool = ...,
        key_agreement: builtins.bool = ...,
        key_encipherment: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_sign", b"cert_sign", "content_commitment", b"content_commitment", "crl_sign", b"crl_sign", "data_encipherment", b"data_encipherment", "decipher_only", b"decipher_only", "digital_signature", b"digital_signature", "encipher_only", b"encipher_only", "key_agreement", b"key_agreement", "key_encipherment", b"key_encipherment"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_AUTH_FIELD_NUMBER: builtins.int
    CODE_SIGNING_FIELD_NUMBER: builtins.int
    EMAIL_PROTECTION_FIELD_NUMBER: builtins.int
    OCSP_SIGNING_FIELD_NUMBER: builtins.int
    SERVER_AUTH_FIELD_NUMBER: builtins.int
    TIME_STAMPING_FIELD_NUMBER: builtins.int
    client_auth: builtins.bool
    code_signing: builtins.bool
    email_protection: builtins.bool
    ocsp_signing: builtins.bool
    server_auth: builtins.bool
    time_stamping: builtins.bool
    def __init__(
        self,
        *,
        client_auth: builtins.bool = ...,
        code_signing: builtins.bool = ...,
        email_protection: builtins.bool = ...,
        ocsp_signing: builtins.bool = ...,
        server_auth: builtins.bool = ...,
        time_stamping: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth", b"client_auth", "code_signing", b"code_signing", "email_protection", b"email_protection", "ocsp_signing", b"ocsp_signing", "server_auth", b"server_auth", "time_stamping", b"time_stamping"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_KEY_USAGE_FIELD_NUMBER: builtins.int
    EXTENDED_KEY_USAGE_FIELD_NUMBER: builtins.int
    UNKNOWN_EXTENDED_KEY_USAGES_FIELD_NUMBER: builtins.int
    @property
    def base_key_usage(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage: ...
    @property
    def extended_key_usage(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage: ...
    @property
    def unknown_extended_key_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages]: ...
    def __init__(
        self,
        *,
        base_key_usage: global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXBaseKeyUsage | None = ...,
        extended_key_usage: global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXExtendedKeyUsage | None = ...,
        unknown_extended_key_usages: collections.abc.Iterable[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsageXUnknownExtendedKeyUsages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage", "unknown_extended_key_usages", b"unknown_extended_key_usages"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds = PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXBaselineValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIA_OCSP_SERVERS_FIELD_NUMBER: builtins.int
    ADDITIONAL_EXTENSIONS_FIELD_NUMBER: builtins.int
    CA_OPTIONS_FIELD_NUMBER: builtins.int
    KEY_USAGE_FIELD_NUMBER: builtins.int
    POLICY_IDS_FIELD_NUMBER: builtins.int
    @property
    def aia_ocsp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions]: ...
    @property
    def ca_options(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions: ...
    @property
    def key_usage(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage: ...
    @property
    def policy_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds]: ...
    def __init__(
        self,
        *,
        aia_ocsp_servers: collections.abc.Iterable[builtins.str] | None = ...,
        additional_extensions: collections.abc.Iterable[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXAdditionalExtensions] | None = ...,
        ca_options: global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXCaOptions | None = ...,
        key_usage: global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXKeyUsage | None = ...,
        policy_ids: collections.abc.Iterable[global___PrivatecaCaPoolXIssuancePolicyXBaselineValuesXPolicyIds] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ca_options", b"ca_options", "key_usage", b"key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_extensions", b"additional_extensions", "aia_ocsp_servers", b"aia_ocsp_servers", "ca_options", b"ca_options", "key_usage", b"key_usage", "policy_ids", b"policy_ids"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXBaselineValues = PrivatecaCaPoolXIssuancePolicyXBaselineValues

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression = PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicyXIdentityConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_SUBJECT_ALT_NAMES_PASSTHROUGH_FIELD_NUMBER: builtins.int
    ALLOW_SUBJECT_PASSTHROUGH_FIELD_NUMBER: builtins.int
    CEL_EXPRESSION_FIELD_NUMBER: builtins.int
    allow_subject_alt_names_passthrough: builtins.bool
    allow_subject_passthrough: builtins.bool
    @property
    def cel_expression(self) -> global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression: ...
    def __init__(
        self,
        *,
        allow_subject_alt_names_passthrough: builtins.bool = ...,
        allow_subject_passthrough: builtins.bool = ...,
        cel_expression: global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraintsXCelExpression | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cel_expression", b"cel_expression"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_subject_alt_names_passthrough", b"allow_subject_alt_names_passthrough", "allow_subject_passthrough", b"allow_subject_passthrough", "cel_expression", b"cel_expression"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraints = PrivatecaCaPoolXIssuancePolicyXIdentityConstraints

@typing_extensions.final
class PrivatecaCaPoolXIssuancePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    MAXIMUM_LIFETIME_FIELD_NUMBER: builtins.int
    ALLOWED_ISSUANCE_MODES_FIELD_NUMBER: builtins.int
    ALLOWED_KEY_TYPES_FIELD_NUMBER: builtins.int
    BASELINE_VALUES_FIELD_NUMBER: builtins.int
    IDENTITY_CONSTRAINTS_FIELD_NUMBER: builtins.int
    maximum_lifetime: builtins.str
    @property
    def allowed_issuance_modes(self) -> global___PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes: ...
    @property
    def allowed_key_types(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes]: ...
    @property
    def baseline_values(self) -> global___PrivatecaCaPoolXIssuancePolicyXBaselineValues: ...
    @property
    def identity_constraints(self) -> global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraints: ...
    def __init__(
        self,
        *,
        maximum_lifetime: builtins.str = ...,
        allowed_issuance_modes: global___PrivatecaCaPoolXIssuancePolicyXAllowedIssuanceModes | None = ...,
        allowed_key_types: collections.abc.Iterable[global___PrivatecaCaPoolXIssuancePolicyXAllowedKeyTypes] | None = ...,
        baseline_values: global___PrivatecaCaPoolXIssuancePolicyXBaselineValues | None = ...,
        identity_constraints: global___PrivatecaCaPoolXIssuancePolicyXIdentityConstraints | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["allowed_issuance_modes", b"allowed_issuance_modes", "baseline_values", b"baseline_values", "identity_constraints", b"identity_constraints"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_issuance_modes", b"allowed_issuance_modes", "allowed_key_types", b"allowed_key_types", "baseline_values", b"baseline_values", "identity_constraints", b"identity_constraints", "maximum_lifetime", b"maximum_lifetime"]) -> None: ...

global___PrivatecaCaPoolXIssuancePolicy = PrivatecaCaPoolXIssuancePolicy

@typing_extensions.final
class PrivatecaCaPoolXPublishingOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLISH_CA_CERT_FIELD_NUMBER: builtins.int
    PUBLISH_CRL_FIELD_NUMBER: builtins.int
    publish_ca_cert: builtins.bool
    publish_crl: builtins.bool
    def __init__(
        self,
        *,
        publish_ca_cert: builtins.bool = ...,
        publish_crl: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["publish_ca_cert", b"publish_ca_cert", "publish_crl", b"publish_crl"]) -> None: ...

global___PrivatecaCaPoolXPublishingOptions = PrivatecaCaPoolXPublishingOptions

@typing_extensions.final
class PrivatecaCaPoolXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PrivatecaCaPoolXTimeouts = PrivatecaCaPoolXTimeouts

@typing_extensions.final
class PrivatecaCaPool(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    ISSUANCE_POLICY_FIELD_NUMBER: builtins.int
    PUBLISHING_OPTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    tier: builtins.str
    @property
    def issuance_policy(self) -> global___PrivatecaCaPoolXIssuancePolicy: ...
    @property
    def publishing_options(self) -> global___PrivatecaCaPoolXPublishingOptions: ...
    @property
    def timeouts(self) -> global___PrivatecaCaPoolXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        tier: builtins.str = ...,
        issuance_policy: global___PrivatecaCaPoolXIssuancePolicy | None = ...,
        publishing_options: global___PrivatecaCaPoolXPublishingOptions | None = ...,
        timeouts: global___PrivatecaCaPoolXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["issuance_policy", b"issuance_policy", "publishing_options", b"publishing_options", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "issuance_policy", b"issuance_policy", "labels", b"labels", "location", b"location", "name", b"name", "project", b"project", "publishing_options", b"publishing_options", "resource_info", b"resource_info", "tier", b"tier", "timeouts", b"timeouts"]) -> None: ...

global___PrivatecaCaPool = PrivatecaCaPool

@typing_extensions.final
class PrivatecaCaPoolIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PrivatecaCaPoolIamBindingXCondition = PrivatecaCaPoolIamBindingXCondition

@typing_extensions.final
class PrivatecaCaPoolIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_POOL_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_pool: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___PrivatecaCaPoolIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_pool: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___PrivatecaCaPoolIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_pool", b"ca_pool", "condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___PrivatecaCaPoolIamBinding = PrivatecaCaPoolIamBinding

@typing_extensions.final
class PrivatecaCaPoolIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PrivatecaCaPoolIamMemberXCondition = PrivatecaCaPoolIamMemberXCondition

@typing_extensions.final
class PrivatecaCaPoolIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_POOL_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_pool: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___PrivatecaCaPoolIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_pool: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___PrivatecaCaPoolIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_pool", b"ca_pool", "condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___PrivatecaCaPoolIamMember = PrivatecaCaPoolIamMember

@typing_extensions.final
class PrivatecaCaPoolIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CA_POOL_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ca_pool: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        ca_pool: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ca_pool", b"ca_pool", "etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___PrivatecaCaPoolIamPolicy = PrivatecaCaPoolIamPolicy

@typing_extensions.final
class PrivatecaCertificateXConfigXPublicKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FORMAT_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    format: builtins.str
    key: builtins.str
    def __init__(
        self,
        *,
        format: builtins.str = ...,
        key: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["format", b"format", "key", b"key"]) -> None: ...

global___PrivatecaCertificateXConfigXPublicKey = PrivatecaCertificateXConfigXPublicKey

@typing_extensions.final
class PrivatecaCertificateXConfigXSubjectConfigXSubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_NAME_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LOCALITY_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNIT_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_FIELD_NUMBER: builtins.int
    STREET_ADDRESS_FIELD_NUMBER: builtins.int
    common_name: builtins.str
    country_code: builtins.str
    locality: builtins.str
    organization: builtins.str
    organizational_unit: builtins.str
    postal_code: builtins.str
    province: builtins.str
    street_address: builtins.str
    def __init__(
        self,
        *,
        common_name: builtins.str = ...,
        country_code: builtins.str = ...,
        locality: builtins.str = ...,
        organization: builtins.str = ...,
        organizational_unit: builtins.str = ...,
        postal_code: builtins.str = ...,
        province: builtins.str = ...,
        street_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_name", b"common_name", "country_code", b"country_code", "locality", b"locality", "organization", b"organization", "organizational_unit", b"organizational_unit", "postal_code", b"postal_code", "province", b"province", "street_address", b"street_address"]) -> None: ...

global___PrivatecaCertificateXConfigXSubjectConfigXSubject = PrivatecaCertificateXConfigXSubjectConfigXSubject

@typing_extensions.final
class PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_NAMES_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    URIS_FIELD_NUMBER: builtins.int
    @property
    def dns_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_names: collections.abc.Iterable[builtins.str] | None = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        uris: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_names", b"dns_names", "email_addresses", b"email_addresses", "ip_addresses", b"ip_addresses", "uris", b"uris"]) -> None: ...

global___PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName = PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName

@typing_extensions.final
class PrivatecaCertificateXConfigXSubjectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_FIELD_NUMBER: builtins.int
    SUBJECT_ALT_NAME_FIELD_NUMBER: builtins.int
    @property
    def subject(self) -> global___PrivatecaCertificateXConfigXSubjectConfigXSubject: ...
    @property
    def subject_alt_name(self) -> global___PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName: ...
    def __init__(
        self,
        *,
        subject: global___PrivatecaCertificateXConfigXSubjectConfigXSubject | None = ...,
        subject_alt_name: global___PrivatecaCertificateXConfigXSubjectConfigXSubjectAltName | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subject", b"subject", "subject_alt_name", b"subject_alt_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subject", b"subject", "subject_alt_name", b"subject_alt_name"]) -> None: ...

global___PrivatecaCertificateXConfigXSubjectConfig = PrivatecaCertificateXConfigXSubjectConfig

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId = PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRITICAL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    critical: builtins.bool
    value: builtins.str
    @property
    def object_id(self) -> global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId: ...
    def __init__(
        self,
        *,
        critical: builtins.bool = ...,
        value: builtins.str = ...,
        object_id: global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensionsXObjectId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["critical", b"critical", "object_id", b"object_id", "value", b"value"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions = PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXCaOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_CA_FIELD_NUMBER: builtins.int
    MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    NON_CA_FIELD_NUMBER: builtins.int
    ZERO_MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    is_ca: builtins.bool
    max_issuer_path_length: builtins.float
    non_ca: builtins.bool
    zero_max_issuer_path_length: builtins.bool
    def __init__(
        self,
        *,
        is_ca: builtins.bool = ...,
        max_issuer_path_length: builtins.float = ...,
        non_ca: builtins.bool = ...,
        zero_max_issuer_path_length: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_ca", b"is_ca", "max_issuer_path_length", b"max_issuer_path_length", "non_ca", b"non_ca", "zero_max_issuer_path_length", b"zero_max_issuer_path_length"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXCaOptions = PrivatecaCertificateXConfigXX509ConfigXCaOptions

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_SIGN_FIELD_NUMBER: builtins.int
    CONTENT_COMMITMENT_FIELD_NUMBER: builtins.int
    CRL_SIGN_FIELD_NUMBER: builtins.int
    DATA_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    DECIPHER_ONLY_FIELD_NUMBER: builtins.int
    DIGITAL_SIGNATURE_FIELD_NUMBER: builtins.int
    ENCIPHER_ONLY_FIELD_NUMBER: builtins.int
    KEY_AGREEMENT_FIELD_NUMBER: builtins.int
    KEY_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    cert_sign: builtins.bool
    content_commitment: builtins.bool
    crl_sign: builtins.bool
    data_encipherment: builtins.bool
    decipher_only: builtins.bool
    digital_signature: builtins.bool
    encipher_only: builtins.bool
    key_agreement: builtins.bool
    key_encipherment: builtins.bool
    def __init__(
        self,
        *,
        cert_sign: builtins.bool = ...,
        content_commitment: builtins.bool = ...,
        crl_sign: builtins.bool = ...,
        data_encipherment: builtins.bool = ...,
        decipher_only: builtins.bool = ...,
        digital_signature: builtins.bool = ...,
        encipher_only: builtins.bool = ...,
        key_agreement: builtins.bool = ...,
        key_encipherment: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_sign", b"cert_sign", "content_commitment", b"content_commitment", "crl_sign", b"crl_sign", "data_encipherment", b"data_encipherment", "decipher_only", b"decipher_only", "digital_signature", b"digital_signature", "encipher_only", b"encipher_only", "key_agreement", b"key_agreement", "key_encipherment", b"key_encipherment"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage = PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_AUTH_FIELD_NUMBER: builtins.int
    CODE_SIGNING_FIELD_NUMBER: builtins.int
    EMAIL_PROTECTION_FIELD_NUMBER: builtins.int
    OCSP_SIGNING_FIELD_NUMBER: builtins.int
    SERVER_AUTH_FIELD_NUMBER: builtins.int
    TIME_STAMPING_FIELD_NUMBER: builtins.int
    client_auth: builtins.bool
    code_signing: builtins.bool
    email_protection: builtins.bool
    ocsp_signing: builtins.bool
    server_auth: builtins.bool
    time_stamping: builtins.bool
    def __init__(
        self,
        *,
        client_auth: builtins.bool = ...,
        code_signing: builtins.bool = ...,
        email_protection: builtins.bool = ...,
        ocsp_signing: builtins.bool = ...,
        server_auth: builtins.bool = ...,
        time_stamping: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth", b"client_auth", "code_signing", b"code_signing", "email_protection", b"email_protection", "ocsp_signing", b"ocsp_signing", "server_auth", b"server_auth", "time_stamping", b"time_stamping"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage = PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages = PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_KEY_USAGE_FIELD_NUMBER: builtins.int
    EXTENDED_KEY_USAGE_FIELD_NUMBER: builtins.int
    UNKNOWN_EXTENDED_KEY_USAGES_FIELD_NUMBER: builtins.int
    @property
    def base_key_usage(self) -> global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage: ...
    @property
    def extended_key_usage(self) -> global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage: ...
    @property
    def unknown_extended_key_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages]: ...
    def __init__(
        self,
        *,
        base_key_usage: global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXBaseKeyUsage | None = ...,
        extended_key_usage: global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXExtendedKeyUsage | None = ...,
        unknown_extended_key_usages: collections.abc.Iterable[global___PrivatecaCertificateXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage", "unknown_extended_key_usages", b"unknown_extended_key_usages"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXKeyUsage = PrivatecaCertificateXConfigXX509ConfigXKeyUsage

@typing_extensions.final
class PrivatecaCertificateXConfigXX509ConfigXPolicyIds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateXConfigXX509ConfigXPolicyIds = PrivatecaCertificateXConfigXX509ConfigXPolicyIds

@typing_extensions.final
class PrivatecaCertificateXConfigXX509Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIA_OCSP_SERVERS_FIELD_NUMBER: builtins.int
    ADDITIONAL_EXTENSIONS_FIELD_NUMBER: builtins.int
    CA_OPTIONS_FIELD_NUMBER: builtins.int
    KEY_USAGE_FIELD_NUMBER: builtins.int
    POLICY_IDS_FIELD_NUMBER: builtins.int
    @property
    def aia_ocsp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions]: ...
    @property
    def ca_options(self) -> global___PrivatecaCertificateXConfigXX509ConfigXCaOptions: ...
    @property
    def key_usage(self) -> global___PrivatecaCertificateXConfigXX509ConfigXKeyUsage: ...
    @property
    def policy_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateXConfigXX509ConfigXPolicyIds]: ...
    def __init__(
        self,
        *,
        aia_ocsp_servers: collections.abc.Iterable[builtins.str] | None = ...,
        additional_extensions: collections.abc.Iterable[global___PrivatecaCertificateXConfigXX509ConfigXAdditionalExtensions] | None = ...,
        ca_options: global___PrivatecaCertificateXConfigXX509ConfigXCaOptions | None = ...,
        key_usage: global___PrivatecaCertificateXConfigXX509ConfigXKeyUsage | None = ...,
        policy_ids: collections.abc.Iterable[global___PrivatecaCertificateXConfigXX509ConfigXPolicyIds] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ca_options", b"ca_options", "key_usage", b"key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_extensions", b"additional_extensions", "aia_ocsp_servers", b"aia_ocsp_servers", "ca_options", b"ca_options", "key_usage", b"key_usage", "policy_ids", b"policy_ids"]) -> None: ...

global___PrivatecaCertificateXConfigXX509Config = PrivatecaCertificateXConfigXX509Config

@typing_extensions.final
class PrivatecaCertificateXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PUBLIC_KEY_FIELD_NUMBER: builtins.int
    SUBJECT_CONFIG_FIELD_NUMBER: builtins.int
    X509_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def public_key(self) -> global___PrivatecaCertificateXConfigXPublicKey: ...
    @property
    def subject_config(self) -> global___PrivatecaCertificateXConfigXSubjectConfig: ...
    @property
    def x509_config(self) -> global___PrivatecaCertificateXConfigXX509Config: ...
    def __init__(
        self,
        *,
        public_key: global___PrivatecaCertificateXConfigXPublicKey | None = ...,
        subject_config: global___PrivatecaCertificateXConfigXSubjectConfig | None = ...,
        x509_config: global___PrivatecaCertificateXConfigXX509Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["public_key", b"public_key", "subject_config", b"subject_config", "x509_config", b"x509_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["public_key", b"public_key", "subject_config", b"subject_config", "x509_config", b"x509_config"]) -> None: ...

global___PrivatecaCertificateXConfig = PrivatecaCertificateXConfig

@typing_extensions.final
class PrivatecaCertificateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PrivatecaCertificateXTimeouts = PrivatecaCertificateXTimeouts

@typing_extensions.final
class PrivatecaCertificate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class CertificateDescriptionEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class RevocationDetailsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    CERTIFICATE_DESCRIPTION_FIELD_NUMBER: builtins.int
    CERTIFICATE_TEMPLATE_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    ISSUER_CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LIFETIME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PEM_CERTIFICATE_FIELD_NUMBER: builtins.int
    PEM_CERTIFICATE_CHAIN_FIELD_NUMBER: builtins.int
    PEM_CERTIFICATES_FIELD_NUMBER: builtins.int
    PEM_CSR_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    REVOCATION_DETAILS_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_authority: builtins.str
    @property
    def certificate_description(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    certificate_template: builtins.str
    create_time: builtins.str
    id: builtins.str
    issuer_certificate_authority: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    lifetime: builtins.str
    location: builtins.str
    name: builtins.str
    pem_certificate: builtins.str
    @property
    def pem_certificate_chain(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def pem_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pem_csr: builtins.str
    pool: builtins.str
    project: builtins.str
    @property
    def revocation_details(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    update_time: builtins.str
    @property
    def config(self) -> global___PrivatecaCertificateXConfig: ...
    @property
    def timeouts(self) -> global___PrivatecaCertificateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_authority: builtins.str = ...,
        certificate_description: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificate_template: builtins.str = ...,
        create_time: builtins.str = ...,
        id: builtins.str = ...,
        issuer_certificate_authority: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        lifetime: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        pem_certificate: builtins.str = ...,
        pem_certificate_chain: collections.abc.Iterable[builtins.str] | None = ...,
        pem_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        pem_csr: builtins.str = ...,
        pool: builtins.str = ...,
        project: builtins.str = ...,
        revocation_details: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        update_time: builtins.str = ...,
        config: global___PrivatecaCertificateXConfig | None = ...,
        timeouts: global___PrivatecaCertificateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority", b"certificate_authority", "certificate_description", b"certificate_description", "certificate_template", b"certificate_template", "config", b"config", "create_time", b"create_time", "id", b"id", "issuer_certificate_authority", b"issuer_certificate_authority", "labels", b"labels", "lifetime", b"lifetime", "location", b"location", "name", b"name", "pem_certificate", b"pem_certificate", "pem_certificate_chain", b"pem_certificate_chain", "pem_certificates", b"pem_certificates", "pem_csr", b"pem_csr", "pool", b"pool", "project", b"project", "resource_info", b"resource_info", "revocation_details", b"revocation_details", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___PrivatecaCertificate = PrivatecaCertificate

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    COMMON_NAME_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LOCALITY_FIELD_NUMBER: builtins.int
    ORGANIZATION_FIELD_NUMBER: builtins.int
    ORGANIZATIONAL_UNIT_FIELD_NUMBER: builtins.int
    POSTAL_CODE_FIELD_NUMBER: builtins.int
    PROVINCE_FIELD_NUMBER: builtins.int
    STREET_ADDRESS_FIELD_NUMBER: builtins.int
    common_name: builtins.str
    country_code: builtins.str
    locality: builtins.str
    organization: builtins.str
    organizational_unit: builtins.str
    postal_code: builtins.str
    province: builtins.str
    street_address: builtins.str
    def __init__(
        self,
        *,
        common_name: builtins.str = ...,
        country_code: builtins.str = ...,
        locality: builtins.str = ...,
        organization: builtins.str = ...,
        organizational_unit: builtins.str = ...,
        postal_code: builtins.str = ...,
        province: builtins.str = ...,
        street_address: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["common_name", b"common_name", "country_code", b"country_code", "locality", b"locality", "organization", b"organization", "organizational_unit", b"organizational_unit", "postal_code", b"postal_code", "province", b"province", "street_address", b"street_address"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject = PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_NAMES_FIELD_NUMBER: builtins.int
    EMAIL_ADDRESSES_FIELD_NUMBER: builtins.int
    IP_ADDRESSES_FIELD_NUMBER: builtins.int
    URIS_FIELD_NUMBER: builtins.int
    @property
    def dns_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def email_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def ip_addresses(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def uris(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        dns_names: collections.abc.Iterable[builtins.str] | None = ...,
        email_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        ip_addresses: collections.abc.Iterable[builtins.str] | None = ...,
        uris: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_names", b"dns_names", "email_addresses", b"email_addresses", "ip_addresses", b"ip_addresses", "uris", b"uris"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName = PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXSubjectConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_FIELD_NUMBER: builtins.int
    SUBJECT_ALT_NAME_FIELD_NUMBER: builtins.int
    @property
    def subject(self) -> global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject: ...
    @property
    def subject_alt_name(self) -> global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName: ...
    def __init__(
        self,
        *,
        subject: global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubject | None = ...,
        subject_alt_name: global___PrivatecaCertificateAuthorityXConfigXSubjectConfigXSubjectAltName | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subject", b"subject", "subject_alt_name", b"subject_alt_name"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subject", b"subject", "subject_alt_name", b"subject_alt_name"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXSubjectConfig = PrivatecaCertificateAuthorityXConfigXSubjectConfig

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId = PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRITICAL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    critical: builtins.bool
    value: builtins.str
    @property
    def object_id(self) -> global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId: ...
    def __init__(
        self,
        *,
        critical: builtins.bool = ...,
        value: builtins.str = ...,
        object_id: global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensionsXObjectId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["critical", b"critical", "object_id", b"object_id", "value", b"value"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions = PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_CA_FIELD_NUMBER: builtins.int
    MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    NON_CA_FIELD_NUMBER: builtins.int
    ZERO_MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    is_ca: builtins.bool
    max_issuer_path_length: builtins.float
    non_ca: builtins.bool
    zero_max_issuer_path_length: builtins.bool
    def __init__(
        self,
        *,
        is_ca: builtins.bool = ...,
        max_issuer_path_length: builtins.float = ...,
        non_ca: builtins.bool = ...,
        zero_max_issuer_path_length: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_ca", b"is_ca", "max_issuer_path_length", b"max_issuer_path_length", "non_ca", b"non_ca", "zero_max_issuer_path_length", b"zero_max_issuer_path_length"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions = PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_SIGN_FIELD_NUMBER: builtins.int
    CONTENT_COMMITMENT_FIELD_NUMBER: builtins.int
    CRL_SIGN_FIELD_NUMBER: builtins.int
    DATA_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    DECIPHER_ONLY_FIELD_NUMBER: builtins.int
    DIGITAL_SIGNATURE_FIELD_NUMBER: builtins.int
    ENCIPHER_ONLY_FIELD_NUMBER: builtins.int
    KEY_AGREEMENT_FIELD_NUMBER: builtins.int
    KEY_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    cert_sign: builtins.bool
    content_commitment: builtins.bool
    crl_sign: builtins.bool
    data_encipherment: builtins.bool
    decipher_only: builtins.bool
    digital_signature: builtins.bool
    encipher_only: builtins.bool
    key_agreement: builtins.bool
    key_encipherment: builtins.bool
    def __init__(
        self,
        *,
        cert_sign: builtins.bool = ...,
        content_commitment: builtins.bool = ...,
        crl_sign: builtins.bool = ...,
        data_encipherment: builtins.bool = ...,
        decipher_only: builtins.bool = ...,
        digital_signature: builtins.bool = ...,
        encipher_only: builtins.bool = ...,
        key_agreement: builtins.bool = ...,
        key_encipherment: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_sign", b"cert_sign", "content_commitment", b"content_commitment", "crl_sign", b"crl_sign", "data_encipherment", b"data_encipherment", "decipher_only", b"decipher_only", "digital_signature", b"digital_signature", "encipher_only", b"encipher_only", "key_agreement", b"key_agreement", "key_encipherment", b"key_encipherment"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage = PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_AUTH_FIELD_NUMBER: builtins.int
    CODE_SIGNING_FIELD_NUMBER: builtins.int
    EMAIL_PROTECTION_FIELD_NUMBER: builtins.int
    OCSP_SIGNING_FIELD_NUMBER: builtins.int
    SERVER_AUTH_FIELD_NUMBER: builtins.int
    TIME_STAMPING_FIELD_NUMBER: builtins.int
    client_auth: builtins.bool
    code_signing: builtins.bool
    email_protection: builtins.bool
    ocsp_signing: builtins.bool
    server_auth: builtins.bool
    time_stamping: builtins.bool
    def __init__(
        self,
        *,
        client_auth: builtins.bool = ...,
        code_signing: builtins.bool = ...,
        email_protection: builtins.bool = ...,
        ocsp_signing: builtins.bool = ...,
        server_auth: builtins.bool = ...,
        time_stamping: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth", b"client_auth", "code_signing", b"code_signing", "email_protection", b"email_protection", "ocsp_signing", b"ocsp_signing", "server_auth", b"server_auth", "time_stamping", b"time_stamping"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage = PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages = PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_KEY_USAGE_FIELD_NUMBER: builtins.int
    EXTENDED_KEY_USAGE_FIELD_NUMBER: builtins.int
    UNKNOWN_EXTENDED_KEY_USAGES_FIELD_NUMBER: builtins.int
    @property
    def base_key_usage(self) -> global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage: ...
    @property
    def extended_key_usage(self) -> global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage: ...
    @property
    def unknown_extended_key_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages]: ...
    def __init__(
        self,
        *,
        base_key_usage: global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXBaseKeyUsage | None = ...,
        extended_key_usage: global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXExtendedKeyUsage | None = ...,
        unknown_extended_key_usages: collections.abc.Iterable[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsageXUnknownExtendedKeyUsages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage", "unknown_extended_key_usages", b"unknown_extended_key_usages"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage = PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds = PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfigXX509Config(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIA_OCSP_SERVERS_FIELD_NUMBER: builtins.int
    ADDITIONAL_EXTENSIONS_FIELD_NUMBER: builtins.int
    CA_OPTIONS_FIELD_NUMBER: builtins.int
    KEY_USAGE_FIELD_NUMBER: builtins.int
    POLICY_IDS_FIELD_NUMBER: builtins.int
    @property
    def aia_ocsp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions]: ...
    @property
    def ca_options(self) -> global___PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions: ...
    @property
    def key_usage(self) -> global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage: ...
    @property
    def policy_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds]: ...
    def __init__(
        self,
        *,
        aia_ocsp_servers: collections.abc.Iterable[builtins.str] | None = ...,
        additional_extensions: collections.abc.Iterable[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXAdditionalExtensions] | None = ...,
        ca_options: global___PrivatecaCertificateAuthorityXConfigXX509ConfigXCaOptions | None = ...,
        key_usage: global___PrivatecaCertificateAuthorityXConfigXX509ConfigXKeyUsage | None = ...,
        policy_ids: collections.abc.Iterable[global___PrivatecaCertificateAuthorityXConfigXX509ConfigXPolicyIds] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ca_options", b"ca_options", "key_usage", b"key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_extensions", b"additional_extensions", "aia_ocsp_servers", b"aia_ocsp_servers", "ca_options", b"ca_options", "key_usage", b"key_usage", "policy_ids", b"policy_ids"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfigXX509Config = PrivatecaCertificateAuthorityXConfigXX509Config

@typing_extensions.final
class PrivatecaCertificateAuthorityXConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    SUBJECT_CONFIG_FIELD_NUMBER: builtins.int
    X509_CONFIG_FIELD_NUMBER: builtins.int
    @property
    def subject_config(self) -> global___PrivatecaCertificateAuthorityXConfigXSubjectConfig: ...
    @property
    def x509_config(self) -> global___PrivatecaCertificateAuthorityXConfigXX509Config: ...
    def __init__(
        self,
        *,
        subject_config: global___PrivatecaCertificateAuthorityXConfigXSubjectConfig | None = ...,
        x509_config: global___PrivatecaCertificateAuthorityXConfigXX509Config | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["subject_config", b"subject_config", "x509_config", b"x509_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["subject_config", b"subject_config", "x509_config", b"x509_config"]) -> None: ...

global___PrivatecaCertificateAuthorityXConfig = PrivatecaCertificateAuthorityXConfig

@typing_extensions.final
class PrivatecaCertificateAuthorityXKeySpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALGORITHM_FIELD_NUMBER: builtins.int
    CLOUD_KMS_KEY_VERSION_FIELD_NUMBER: builtins.int
    algorithm: builtins.str
    cloud_kms_key_version: builtins.str
    def __init__(
        self,
        *,
        algorithm: builtins.str = ...,
        cloud_kms_key_version: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["algorithm", b"algorithm", "cloud_kms_key_version", b"cloud_kms_key_version"]) -> None: ...

global___PrivatecaCertificateAuthorityXKeySpec = PrivatecaCertificateAuthorityXKeySpec

@typing_extensions.final
class PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PEM_CERTIFICATES_FIELD_NUMBER: builtins.int
    @property
    def pem_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        pem_certificates: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["pem_certificates", b"pem_certificates"]) -> None: ...

global___PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain = PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain

@typing_extensions.final
class PrivatecaCertificateAuthorityXSubordinateConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_AUTHORITY_FIELD_NUMBER: builtins.int
    PEM_ISSUER_CHAIN_FIELD_NUMBER: builtins.int
    certificate_authority: builtins.str
    @property
    def pem_issuer_chain(self) -> global___PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain: ...
    def __init__(
        self,
        *,
        certificate_authority: builtins.str = ...,
        pem_issuer_chain: global___PrivatecaCertificateAuthorityXSubordinateConfigXPemIssuerChain | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pem_issuer_chain", b"pem_issuer_chain"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_authority", b"certificate_authority", "pem_issuer_chain", b"pem_issuer_chain"]) -> None: ...

global___PrivatecaCertificateAuthorityXSubordinateConfig = PrivatecaCertificateAuthorityXSubordinateConfig

@typing_extensions.final
class PrivatecaCertificateAuthorityXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PrivatecaCertificateAuthorityXTimeouts = PrivatecaCertificateAuthorityXTimeouts

@typing_extensions.final
class PrivatecaCertificateAuthority(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class AccessUrlsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    ACCESS_URLS_FIELD_NUMBER: builtins.int
    CERTIFICATE_AUTHORITY_ID_FIELD_NUMBER: builtins.int
    CREATE_TIME_FIELD_NUMBER: builtins.int
    DELETION_PROTECTION_FIELD_NUMBER: builtins.int
    DESIRED_STATE_FIELD_NUMBER: builtins.int
    GCS_BUCKET_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    IGNORE_ACTIVE_CERTIFICATES_ON_DELETION_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LIFETIME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PEM_CA_CERTIFICATE_FIELD_NUMBER: builtins.int
    PEM_CA_CERTIFICATES_FIELD_NUMBER: builtins.int
    POOL_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    STATE_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    CONFIG_FIELD_NUMBER: builtins.int
    KEY_SPEC_FIELD_NUMBER: builtins.int
    SUBORDINATE_CONFIG_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def access_urls(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    certificate_authority_id: builtins.str
    create_time: builtins.str
    deletion_protection: builtins.bool
    desired_state: builtins.str
    gcs_bucket: builtins.str
    id: builtins.str
    ignore_active_certificates_on_deletion: builtins.bool
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    lifetime: builtins.str
    location: builtins.str
    name: builtins.str
    pem_ca_certificate: builtins.str
    @property
    def pem_ca_certificates(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    pool: builtins.str
    project: builtins.str
    state: builtins.str
    type: builtins.str
    update_time: builtins.str
    @property
    def config(self) -> global___PrivatecaCertificateAuthorityXConfig: ...
    @property
    def key_spec(self) -> global___PrivatecaCertificateAuthorityXKeySpec: ...
    @property
    def subordinate_config(self) -> global___PrivatecaCertificateAuthorityXSubordinateConfig: ...
    @property
    def timeouts(self) -> global___PrivatecaCertificateAuthorityXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        access_urls: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        certificate_authority_id: builtins.str = ...,
        create_time: builtins.str = ...,
        deletion_protection: builtins.bool = ...,
        desired_state: builtins.str = ...,
        gcs_bucket: builtins.str = ...,
        id: builtins.str = ...,
        ignore_active_certificates_on_deletion: builtins.bool = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        lifetime: builtins.str = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        pem_ca_certificate: builtins.str = ...,
        pem_ca_certificates: collections.abc.Iterable[builtins.str] | None = ...,
        pool: builtins.str = ...,
        project: builtins.str = ...,
        state: builtins.str = ...,
        type: builtins.str = ...,
        update_time: builtins.str = ...,
        config: global___PrivatecaCertificateAuthorityXConfig | None = ...,
        key_spec: global___PrivatecaCertificateAuthorityXKeySpec | None = ...,
        subordinate_config: global___PrivatecaCertificateAuthorityXSubordinateConfig | None = ...,
        timeouts: global___PrivatecaCertificateAuthorityXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["config", b"config", "key_spec", b"key_spec", "resource_info", b"resource_info", "subordinate_config", b"subordinate_config", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["access_urls", b"access_urls", "certificate_authority_id", b"certificate_authority_id", "config", b"config", "create_time", b"create_time", "deletion_protection", b"deletion_protection", "desired_state", b"desired_state", "gcs_bucket", b"gcs_bucket", "id", b"id", "ignore_active_certificates_on_deletion", b"ignore_active_certificates_on_deletion", "key_spec", b"key_spec", "labels", b"labels", "lifetime", b"lifetime", "location", b"location", "name", b"name", "pem_ca_certificate", b"pem_ca_certificate", "pem_ca_certificates", b"pem_ca_certificates", "pool", b"pool", "project", b"project", "resource_info", b"resource_info", "state", b"state", "subordinate_config", b"subordinate_config", "timeouts", b"timeouts", "type", b"type", "update_time", b"update_time"]) -> None: ...

global___PrivatecaCertificateAuthority = PrivatecaCertificateAuthority

@typing_extensions.final
class PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    location: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        location: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "location", b"location", "title", b"title"]) -> None: ...

global___PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression = PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression

@typing_extensions.final
class PrivatecaCertificateTemplateXIdentityConstraints(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOW_SUBJECT_ALT_NAMES_PASSTHROUGH_FIELD_NUMBER: builtins.int
    ALLOW_SUBJECT_PASSTHROUGH_FIELD_NUMBER: builtins.int
    CEL_EXPRESSION_FIELD_NUMBER: builtins.int
    allow_subject_alt_names_passthrough: builtins.bool
    allow_subject_passthrough: builtins.bool
    @property
    def cel_expression(self) -> global___PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression: ...
    def __init__(
        self,
        *,
        allow_subject_alt_names_passthrough: builtins.bool = ...,
        allow_subject_passthrough: builtins.bool = ...,
        cel_expression: global___PrivatecaCertificateTemplateXIdentityConstraintsXCelExpression | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cel_expression", b"cel_expression"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["allow_subject_alt_names_passthrough", b"allow_subject_alt_names_passthrough", "allow_subject_passthrough", b"allow_subject_passthrough", "cel_expression", b"cel_expression"]) -> None: ...

global___PrivatecaCertificateTemplateXIdentityConstraints = PrivatecaCertificateTemplateXIdentityConstraints

@typing_extensions.final
class PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions = PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions

@typing_extensions.final
class PrivatecaCertificateTemplateXPassthroughExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KNOWN_EXTENSIONS_FIELD_NUMBER: builtins.int
    ADDITIONAL_EXTENSIONS_FIELD_NUMBER: builtins.int
    @property
    def known_extensions(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions]: ...
    def __init__(
        self,
        *,
        known_extensions: collections.abc.Iterable[builtins.str] | None = ...,
        additional_extensions: collections.abc.Iterable[global___PrivatecaCertificateTemplateXPassthroughExtensionsXAdditionalExtensions] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_extensions", b"additional_extensions", "known_extensions", b"known_extensions"]) -> None: ...

global___PrivatecaCertificateTemplateXPassthroughExtensions = PrivatecaCertificateTemplateXPassthroughExtensions

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId = PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CRITICAL_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OBJECT_ID_FIELD_NUMBER: builtins.int
    critical: builtins.bool
    value: builtins.str
    @property
    def object_id(self) -> global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId: ...
    def __init__(
        self,
        *,
        critical: builtins.bool = ...,
        value: builtins.str = ...,
        object_id: global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensionsXObjectId | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["object_id", b"object_id"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["critical", b"critical", "object_id", b"object_id", "value", b"value"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions = PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXCaOptions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    IS_CA_FIELD_NUMBER: builtins.int
    MAX_ISSUER_PATH_LENGTH_FIELD_NUMBER: builtins.int
    is_ca: builtins.bool
    max_issuer_path_length: builtins.float
    def __init__(
        self,
        *,
        is_ca: builtins.bool = ...,
        max_issuer_path_length: builtins.float = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["is_ca", b"is_ca", "max_issuer_path_length", b"max_issuer_path_length"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXCaOptions = PrivatecaCertificateTemplateXPredefinedValuesXCaOptions

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERT_SIGN_FIELD_NUMBER: builtins.int
    CONTENT_COMMITMENT_FIELD_NUMBER: builtins.int
    CRL_SIGN_FIELD_NUMBER: builtins.int
    DATA_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    DECIPHER_ONLY_FIELD_NUMBER: builtins.int
    DIGITAL_SIGNATURE_FIELD_NUMBER: builtins.int
    ENCIPHER_ONLY_FIELD_NUMBER: builtins.int
    KEY_AGREEMENT_FIELD_NUMBER: builtins.int
    KEY_ENCIPHERMENT_FIELD_NUMBER: builtins.int
    cert_sign: builtins.bool
    content_commitment: builtins.bool
    crl_sign: builtins.bool
    data_encipherment: builtins.bool
    decipher_only: builtins.bool
    digital_signature: builtins.bool
    encipher_only: builtins.bool
    key_agreement: builtins.bool
    key_encipherment: builtins.bool
    def __init__(
        self,
        *,
        cert_sign: builtins.bool = ...,
        content_commitment: builtins.bool = ...,
        crl_sign: builtins.bool = ...,
        data_encipherment: builtins.bool = ...,
        decipher_only: builtins.bool = ...,
        digital_signature: builtins.bool = ...,
        encipher_only: builtins.bool = ...,
        key_agreement: builtins.bool = ...,
        key_encipherment: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["cert_sign", b"cert_sign", "content_commitment", b"content_commitment", "crl_sign", b"crl_sign", "data_encipherment", b"data_encipherment", "decipher_only", b"decipher_only", "digital_signature", b"digital_signature", "encipher_only", b"encipher_only", "key_agreement", b"key_agreement", "key_encipherment", b"key_encipherment"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage = PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLIENT_AUTH_FIELD_NUMBER: builtins.int
    CODE_SIGNING_FIELD_NUMBER: builtins.int
    EMAIL_PROTECTION_FIELD_NUMBER: builtins.int
    OCSP_SIGNING_FIELD_NUMBER: builtins.int
    SERVER_AUTH_FIELD_NUMBER: builtins.int
    TIME_STAMPING_FIELD_NUMBER: builtins.int
    client_auth: builtins.bool
    code_signing: builtins.bool
    email_protection: builtins.bool
    ocsp_signing: builtins.bool
    server_auth: builtins.bool
    time_stamping: builtins.bool
    def __init__(
        self,
        *,
        client_auth: builtins.bool = ...,
        code_signing: builtins.bool = ...,
        email_protection: builtins.bool = ...,
        ocsp_signing: builtins.bool = ...,
        server_auth: builtins.bool = ...,
        time_stamping: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["client_auth", b"client_auth", "code_signing", b"code_signing", "email_protection", b"email_protection", "ocsp_signing", b"ocsp_signing", "server_auth", b"server_auth", "time_stamping", b"time_stamping"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage = PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages = PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    BASE_KEY_USAGE_FIELD_NUMBER: builtins.int
    EXTENDED_KEY_USAGE_FIELD_NUMBER: builtins.int
    UNKNOWN_EXTENDED_KEY_USAGES_FIELD_NUMBER: builtins.int
    @property
    def base_key_usage(self) -> global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage: ...
    @property
    def extended_key_usage(self) -> global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage: ...
    @property
    def unknown_extended_key_usages(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages]: ...
    def __init__(
        self,
        *,
        base_key_usage: global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXBaseKeyUsage | None = ...,
        extended_key_usage: global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXExtendedKeyUsage | None = ...,
        unknown_extended_key_usages: collections.abc.Iterable[global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsageXUnknownExtendedKeyUsages] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["base_key_usage", b"base_key_usage", "extended_key_usage", b"extended_key_usage", "unknown_extended_key_usages", b"unknown_extended_key_usages"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage = PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    OBJECT_ID_PATH_FIELD_NUMBER: builtins.int
    @property
    def object_id_path(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.float]: ...
    def __init__(
        self,
        *,
        object_id_path: collections.abc.Iterable[builtins.float] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["object_id_path", b"object_id_path"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds = PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds

@typing_extensions.final
class PrivatecaCertificateTemplateXPredefinedValues(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    AIA_OCSP_SERVERS_FIELD_NUMBER: builtins.int
    ADDITIONAL_EXTENSIONS_FIELD_NUMBER: builtins.int
    CA_OPTIONS_FIELD_NUMBER: builtins.int
    KEY_USAGE_FIELD_NUMBER: builtins.int
    POLICY_IDS_FIELD_NUMBER: builtins.int
    @property
    def aia_ocsp_servers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def additional_extensions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions]: ...
    @property
    def ca_options(self) -> global___PrivatecaCertificateTemplateXPredefinedValuesXCaOptions: ...
    @property
    def key_usage(self) -> global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage: ...
    @property
    def policy_ids(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds]: ...
    def __init__(
        self,
        *,
        aia_ocsp_servers: collections.abc.Iterable[builtins.str] | None = ...,
        additional_extensions: collections.abc.Iterable[global___PrivatecaCertificateTemplateXPredefinedValuesXAdditionalExtensions] | None = ...,
        ca_options: global___PrivatecaCertificateTemplateXPredefinedValuesXCaOptions | None = ...,
        key_usage: global___PrivatecaCertificateTemplateXPredefinedValuesXKeyUsage | None = ...,
        policy_ids: collections.abc.Iterable[global___PrivatecaCertificateTemplateXPredefinedValuesXPolicyIds] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["ca_options", b"ca_options", "key_usage", b"key_usage"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["additional_extensions", b"additional_extensions", "aia_ocsp_servers", b"aia_ocsp_servers", "ca_options", b"ca_options", "key_usage", b"key_usage", "policy_ids", b"policy_ids"]) -> None: ...

global___PrivatecaCertificateTemplateXPredefinedValues = PrivatecaCertificateTemplateXPredefinedValues

@typing_extensions.final
class PrivatecaCertificateTemplateXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___PrivatecaCertificateTemplateXTimeouts = PrivatecaCertificateTemplateXTimeouts

@typing_extensions.final
class PrivatecaCertificateTemplate(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    CREATE_TIME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UPDATE_TIME_FIELD_NUMBER: builtins.int
    IDENTITY_CONSTRAINTS_FIELD_NUMBER: builtins.int
    PASSTHROUGH_EXTENSIONS_FIELD_NUMBER: builtins.int
    PREDEFINED_VALUES_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    create_time: builtins.str
    description: builtins.str
    id: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    location: builtins.str
    name: builtins.str
    project: builtins.str
    update_time: builtins.str
    @property
    def identity_constraints(self) -> global___PrivatecaCertificateTemplateXIdentityConstraints: ...
    @property
    def passthrough_extensions(self) -> global___PrivatecaCertificateTemplateXPassthroughExtensions: ...
    @property
    def predefined_values(self) -> global___PrivatecaCertificateTemplateXPredefinedValues: ...
    @property
    def timeouts(self) -> global___PrivatecaCertificateTemplateXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        create_time: builtins.str = ...,
        description: builtins.str = ...,
        id: builtins.str = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        update_time: builtins.str = ...,
        identity_constraints: global___PrivatecaCertificateTemplateXIdentityConstraints | None = ...,
        passthrough_extensions: global___PrivatecaCertificateTemplateXPassthroughExtensions | None = ...,
        predefined_values: global___PrivatecaCertificateTemplateXPredefinedValues | None = ...,
        timeouts: global___PrivatecaCertificateTemplateXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["identity_constraints", b"identity_constraints", "passthrough_extensions", b"passthrough_extensions", "predefined_values", b"predefined_values", "resource_info", b"resource_info", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["create_time", b"create_time", "description", b"description", "id", b"id", "identity_constraints", b"identity_constraints", "labels", b"labels", "location", b"location", "name", b"name", "passthrough_extensions", b"passthrough_extensions", "predefined_values", b"predefined_values", "project", b"project", "resource_info", b"resource_info", "timeouts", b"timeouts", "update_time", b"update_time"]) -> None: ...

global___PrivatecaCertificateTemplate = PrivatecaCertificateTemplate

@typing_extensions.final
class PrivatecaCertificateTemplateIamBindingXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PrivatecaCertificateTemplateIamBindingXCondition = PrivatecaCertificateTemplateIamBindingXCondition

@typing_extensions.final
class PrivatecaCertificateTemplateIamBinding(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_TEMPLATE_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBERS_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_template: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    @property
    def members(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___PrivatecaCertificateTemplateIamBindingXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_template: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        members: collections.abc.Iterable[builtins.str] | None = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___PrivatecaCertificateTemplateIamBindingXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_template", b"certificate_template", "condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "members", b"members", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___PrivatecaCertificateTemplateIamBinding = PrivatecaCertificateTemplateIamBinding

@typing_extensions.final
class PrivatecaCertificateTemplateIamMemberXCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DESCRIPTION_FIELD_NUMBER: builtins.int
    EXPRESSION_FIELD_NUMBER: builtins.int
    TITLE_FIELD_NUMBER: builtins.int
    description: builtins.str
    expression: builtins.str
    title: builtins.str
    def __init__(
        self,
        *,
        description: builtins.str = ...,
        expression: builtins.str = ...,
        title: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "expression", b"expression", "title", b"title"]) -> None: ...

global___PrivatecaCertificateTemplateIamMemberXCondition = PrivatecaCertificateTemplateIamMemberXCondition

@typing_extensions.final
class PrivatecaCertificateTemplateIamMember(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_TEMPLATE_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    MEMBER_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    ROLE_FIELD_NUMBER: builtins.int
    CONDITION_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_template: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    member: builtins.str
    project: builtins.str
    role: builtins.str
    @property
    def condition(self) -> global___PrivatecaCertificateTemplateIamMemberXCondition: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_template: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        member: builtins.str = ...,
        project: builtins.str = ...,
        role: builtins.str = ...,
        condition: global___PrivatecaCertificateTemplateIamMemberXCondition | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["condition", b"condition", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_template", b"certificate_template", "condition", b"condition", "etag", b"etag", "id", b"id", "location", b"location", "member", b"member", "project", b"project", "resource_info", b"resource_info", "role", b"role"]) -> None: ...

global___PrivatecaCertificateTemplateIamMember = PrivatecaCertificateTemplateIamMember

@typing_extensions.final
class PrivatecaCertificateTemplateIamPolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CERTIFICATE_TEMPLATE_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    POLICY_DATA_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    certificate_template: builtins.str
    etag: builtins.str
    id: builtins.str
    location: builtins.str
    policy_data: builtins.str
    project: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        certificate_template: builtins.str = ...,
        etag: builtins.str = ...,
        id: builtins.str = ...,
        location: builtins.str = ...,
        policy_data: builtins.str = ...,
        project: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["certificate_template", b"certificate_template", "etag", b"etag", "id", b"id", "location", b"location", "policy_data", b"policy_data", "project", b"project", "resource_info", b"resource_info"]) -> None: ...

global___PrivatecaCertificateTemplateIamPolicy = PrivatecaCertificateTemplateIamPolicy



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import gcp.gcp_dns_pb2
import google.protobuf.descriptor
import google.protobuf.message
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class GoogleDns(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DNS_MANAGED_ZONE_FIELD_NUMBER: builtins.int
    DNS_POLICY_FIELD_NUMBER: builtins.int
    DNS_RECORD_SET_FIELD_NUMBER: builtins.int
    @property
    def dns_managed_zone(self) -> gcp.gcp_dns_pb2.DnsManagedZone: ...
    @property
    def dns_policy(self) -> gcp.gcp_dns_pb2.DnsPolicy: ...
    @property
    def dns_record_set(self) -> gcp.gcp_dns_pb2.DnsRecordSet: ...
    def __init__(
        self,
        *,
        dns_managed_zone: gcp.gcp_dns_pb2.DnsManagedZone | None = ...,
        dns_policy: gcp.gcp_dns_pb2.DnsPolicy | None = ...,
        dns_record_set: gcp.gcp_dns_pb2.DnsRecordSet | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["dns_managed_zone", b"dns_managed_zone", "dns_policy", b"dns_policy", "dns_record_set", b"dns_record_set"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["dns_managed_zone", b"dns_managed_zone", "dns_policy", b"dns_policy", "dns_record_set", b"dns_record_set"]) -> None: ...

global___GoogleDns = GoogleDns
